@@ -15,7 +15,9 @@ use constant {
 };
 
 use overload
-  '""' => \&Cwd::getcwd,
+  bool => sub { defined $_[0] },
+  '""' => sub { Cwd::getcwd() },
+  '0+' => sub { Scalar::Util::refaddr($_[0]) },
   fallback => 1
 ;
 
@@ -27,7 +29,7 @@ BEGIN {
   our @EXPORT_TAGS = ();
 }
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION; # so "use Module 0.002" won't warn on underscore
 
 my $_FINAL_ERRNO;
@@ -44,7 +46,7 @@ sub new {
     _initialized => 0,
   }, $class;
 
-  if (defined $dir && !$self->pushd($dir)) {
+  if (defined $dir && !defined $self->pushd($dir)) {
     return undef;
   }
 
@@ -133,7 +135,7 @@ sub DESTROY {
   my $self = shift;
 
   local($., $@, $!, $^E, $?); # recommended by perldoc perlobj
-  if ($self->backout()) {
+  if (defined $self->backout()) {
     undef $_FINAL_ERRNO;
     undef $_FINAL_ERROR;
   }
